@@ -18,7 +18,7 @@ class PushRequest(View):
         try:
             body = json.loads(self.request.body.decode('utf-8'))
             branch_name = body['push']['changes'][0]['new']['name']
-            if branch_name == settings.SERVER_BRANCH:
+            if branch_name == getattr(settings, 'SERVER_BRANCH', 'server'):
                 if server_settings.get('PASSWORD', None):
                     call_command('update_project', server_settings['PROJECT_NAME'], server_settings['HOST'],
                                  server_settings['USER'],
